@@ -191,6 +191,14 @@ create.xlsx.report <- function(config,study.list){
     sapply(study.list, function(x) return(format(x$rowcount.step1, big.mark="," , scientific = FALSE))),
     sapply(study.list, function(x) return(format(x$rowcount.step2, big.mark="," , scientific = FALSE))),
     sapply(study.list, function(x) return(format(x$rowcount.step3, big.mark="," , scientific = FALSE))),
+    sapply(study.list, function(x) return(calculatePercent(sum(as.numeric(gsub(x=x$tables$multi_allele_count_preProcess[1:3],
+                                                                                                pattern = ",",
+                                                                                                replacement = ""))),x$rowcount.step3,pretty=TRUE))),
+    sapply(study.list, function(x) return(calculatePercent(sum(as.numeric(gsub(x=x$tables$multi_allele_count_preProcess[4:6],
+                                                                                                    pattern = ",",
+                                                                                                    replacement = "")))
+                                                                                ,x$rowcount.step3,
+                                                                                pretty=TRUE))),
     sapply(study.list, function(x) return(calculatePercent(x$monomorphic.count,x$rowcount.step3,pretty=TRUE))),
     #sapply(study.list, function(x) return(calculatePercent(x$duplicate.count,x$rowcount.step3,pretty=TRUE))),
     sapply(study.list, function(x) return(calculatePercent(x$palindromic.rows,x$rowcount.step3,pretty=TRUE))),
@@ -232,6 +240,8 @@ create.xlsx.report <- function(config,study.list){
                               'Variant count after step 1 *',
                               'Variant count after step 2 **',
                               'Variant count after step 3 ***',
+                              'SNP variants',
+                              'Non-SNP variants',
                               'Monomorphic',
 #/	'Duplicates',
                               'Palindromics',
